@@ -128,7 +128,7 @@ class LocalRepo:
             :rtype: dict[list[str]] """
         todos = []
         for path in self.path.get_paths_recursive():
-            if path.name().lower() in ("shelved.patch", "readme.md") or any([exclude.replace("*", "") in path for exclude in self.git_exclude_lines]):
+            if path.match(*self.git_exclude_lines, "shelved.patch", "readme.md"):
                 continue
             try:
                 text = path.text.read()
@@ -173,12 +173,10 @@ class LocalRepo:
     def pip_install(self):
         """ Install this repository with pip, WITHOUT -e flag.
             Subprocess messed up -e flag compared to doing it in terminal, so use the normal one."""
-        # subprocess.call(f"python -m pip install {self.path}")
         subprocess.check_call([sys.executable, "-m", "pip", "install", str(self.path)])
 
     def unittest(self):
         """ Run unittests for this repository. """
-        # subprocess.call(f"python -m unittest discover {self.get_test_path()}")
         subprocess.check_call([sys.executable, "-m", "unittest", "discover", str(self.get_test_path())])
 
     def create_sdist(self):
